@@ -25,8 +25,7 @@
 # *  e-mail address 'scipion@cnb.csic.es'
 # *
 # **************************************************************************
-
-
+import enum
 import os
 from datetime import datetime
 from collections import OrderedDict
@@ -101,12 +100,16 @@ SAME_AS_PICKING = 0
 OTHER = 1
 
 
+class ProtExtractParticlesOutput(enum.Enum):
+    """Predefined outputs for particle extraction protocols"""
+    outputParticles = emobj.SetOfParticles
+
 class ProtExtractParticles(ProtParticles):
     """ Base class for all extract-particles protocols.
      This class will take care of the streaming functionality and
      derived classes should mainly overwrite the '_extractMicrograph' function.
      """
-
+    _possibleOutputs = ProtExtractParticlesOutput
     # --------------------------- DEFINE param functions ------------------------
     def _defineParams(self, form):
         form.addSection(label='Input')
@@ -555,7 +558,7 @@ class ProtExtractParticles(ProtParticles):
         pass
 
     def _updateOutputPartSet(self, micList, streamMode):
-        outputName = 'outputParticles'
+        outputName = ProtExtractParticlesOutput.outputParticles.name
         outputParts = getattr(self, outputName, None)
         firstTime = True
 
