@@ -139,6 +139,55 @@ class EmWizard(pwizard.Wizard):
 #    Wizards base classes
 # ===============================================================================
 
+class VariableWizard(pwizard.Wizard):
+    """Wizard base class object where input and output paramNames can be modified and added, so
+    one wizard can be used in several protocols with parameters of different names"""
+    #Variables _targets, _inputs and _outputs must be created in sons
+    # _targets, _inputs, _outputs = [], {}, {}
+
+    def addTarget(self, protocol, targets, inputs, outputs):
+        '''Add a target to a wizard and the input and output parameters are stored in a dictionary with
+        (protocol, targetParamName) as key.
+        Targets must be added one by one.'''
+        self._targets += [(protocol, targets)]
+        self._inputs.update({(protocol, targets[0]): inputs})
+        self._outputs.update({(protocol, targets[0]): outputs})
+
+    def getInputOutput(self, form):
+        '''Retrieving input and output paramNames corresponding to the protocol and target of the wizard clicked'''
+        outParam = ''
+        for target in self._targets:
+            if form.wizParamName == target[1][0] and form.protocol.__class__ == target[0]:
+                prot, target = (target[0], target[1][0])
+                inParams, outParam = self._inputs[(prot, target)], self._outputs[(prot, target)]
+                inParams = self.filterPresentInputs(inParams, form.protocol)
+        return inParams, outParam
+
+    def filterPresentInputs(self, inputParams, protocol):
+        '''Filter the inputs to allow flexibility:
+        1) InputParams can be lists: the first not None parameter of the list will be chosen.
+        2) InputParams can be dict: key -> EnumParam (or IntParam) which functions as index
+                                    value -> list containing paramNames. The hey index element will be chosen
+        '''
+        fInpParams = []
+        for inPar in inputParams:
+            if type(inPar) == list:
+                present = ''
+                for option in inPar:
+                    if getattr(protocol, option).get():
+                        present = option
+                        break
+                fInpParams.append(present)
+            elif type(inPar) == dict:
+                idxParam = list(inPar.keys())[0]
+                optionParams = inPar[idxParam]
+
+                idx = getattr(protocol, idxParam).get()
+                fInpParams.append(optionParams[idx])
+            else:
+                fInpParams.append(inPar)
+        return fInpParams
+
 class DownsampleWizard(EmWizard):
 
     def show(self, form, value, label, units=emcts.UNIT_PIXEL):
