@@ -27,7 +27,7 @@
 """ This module is for Actual wizards to be able to be discovered from the
 Domain. wizard.py is left for wizard models and base classes."""
 import decimal
-import os
+import os, json
 import requests
 
 import pyworkflow.object as pwobj
@@ -37,10 +37,11 @@ from pyworkflow.gui.tree import ListTreeProviderString
 
 import pwem.convert as emconv
 
-from pwem.wizards.wizard import EmWizard, FormulaDialog, ColorScaleWizardBase
+from pwem.wizards.wizard import EmWizard, FormulaDialog, ColorScaleWizardBase, VariableWizard
 import pwem.protocols as emprot
 import pwem.viewers as emview
 import pwem.objects as emobj
+from pwem.constants import RESIDUES3TO1, RESIDUES1TO3
 
 
 class ImportAcquisitionWizard(EmWizard):
@@ -158,27 +159,93 @@ class ChangeOriginSamplingWizard(pwizard.Wizard):
         form.setVar('z', round(z, 3))
         form.setVar('samplingRate', round(sampling, 3))
 
-
 class GetStructureChainsWizard(pwizard.Wizard):
-    """Load an atomic structure, parse chain related information as
-       name, number of residues, list of aminoacids (or other residues)"""
-    _targets = [(emprot.ProtImportSequence, ['inputStructureChain'])
-                # NOTE: be careful if you change this class since
-                # chimera-wizard inherits from it.
-                # (ChimeraModelFromTemplate, ['inputStructureChain'])
-                # (atomstructutils, ['inputStructureChain'])
-                ]
+  # WARNING: this wizard is deprecated. Instead, SelectChainWizard must be used, where inputs, targets and outputs
+  # can be specified.
+  """Load an atomic structure, parse chain related information as
+     name, number of residues, list of aminoacids (or other residues)"""
+  _targets = [(emprot.ProtImportSequence, ['inputStructureChain'])
+              # NOTE: be careful if you change this class since
+              # chimera-wizard inherits from it.
+              # (ChimeraModelFromTemplate, ['inputStructureChain'])
+              # (atomstructutils, ['inputStructureChain'])
+              ]
+
+  @classmethod
+  def getModelsChainsStep(cls, protocol):
+    """ Returns (1) list with the information
+       {"model": %d, "chain": "%s", "residues": %d} (modelsLength)
+       (2) list with residues, position and chain (modelsFirstResidue)"""
+    structureHandler = emconv.AtomicStructHandler()
+    fileName = ""
+    if hasattr(protocol, 'pdbId'):
+      if protocol.pdbId.get() is not None:
+        pdbID = protocol.pdbId.get()
+        url = "https://www.rcsb.org/structure/"
+        URL = url + ("%s" % pdbID)
+        try:
+          response = requests.get(URL)
+        except:
+          raise Exception("Cannot connect to PDB server")
+        if (response.status_code >= 400) and (response.status_code < 500):
+          raise Exception("%s is a wrong PDB ID" % pdbID)
+        fileName = structureHandler.readFromPDBDatabase(
+          os.path.basename(pdbID), dir="/tmp/")
+      else:
+        fileName = protocol.pdbFile.get()
+    else:
+      if protocol.pdbFileToBeRefined.get() is not None:
+        fileName = os.path.abspath(protocol.pdbFileToBeRefined.get(
+        ).getFileName())
+
+    structureHandler.read(fileName)
+    structureHandler.getStructure()
+    # listOfChains, listOfResidues = structureHandler.getModelsChains()
+    return structureHandler.getModelsChains()
+
+  def editionListOfChains(self, listOfChains):
+    self.chainList = []
+    for model, chainDic in listOfChains.items():
+      for chainID, lenResidues in chainDic.items():
+        self.chainList.append(
+          '{"model": %d, "chain": "%s", "residues": %d}' %
+          (model, str(chainID), lenResidues))
+
+  def show(self, form, *params):
+    protocol = form.protocol
+    try:
+      listOfChains, listOfResidues = self.getModelsChainsStep(protocol)
+    except Exception as e:
+      print("ERROR: ", e)
+      return
+
+    self.editionListOfChains(listOfChains)
+    finalChainList = []
+    for i in self.chainList:
+      finalChainList.append(pwobj.String(i))
+    provider = ListTreeProviderString(finalChainList)
+    dlg = dialog.ListDialog(form.root, "Model chains", provider,
+                            "Select one of the chains (model, chain, "
+                            "number of chain residues)")
+    form.setVar('inputStructureChain', dlg.values[0].get())
+
+class SelectChainWizard(VariableWizard):
+    '''Opens the input AtomStruct and allows you to select one of the present chains'''
+    _targets, _inputs, _outputs = [], {}, {}
 
     @classmethod
-    def getModelsChainsStep(cls, protocol):
+    def getModelsChainsStep(cls, protocol, inputParamName):
         """ Returns (1) list with the information
            {"model": %d, "chain": "%s", "residues": %d} (modelsLength)
            (2) list with residues, position and chain (modelsFirstResidue)"""
         structureHandler = emconv.AtomicStructHandler()
         fileName = ""
-        if hasattr(protocol, 'pdbId'):
-            if protocol.pdbId.get() is not None:
-                pdbID = protocol.pdbId.get()
+        AS = getattr(protocol, inputParamName).get()
+        if type(AS) == str:
+            if os.path.exists(AS):
+                fileName = AS
+            else:
+                pdbID = AS
                 url = "https://www.rcsb.org/structure/"
                 URL = url + ("%s" % pdbID)
                 try:
@@ -187,45 +254,115 @@ class GetStructureChainsWizard(pwizard.Wizard):
                     raise Exception("Cannot connect to PDB server")
                 if (response.status_code >= 400) and (response.status_code < 500):
                     raise Exception("%s is a wrong PDB ID" % pdbID)
-                fileName = structureHandler.readFromPDBDatabase(
-                    os.path.basename(pdbID), dir="/tmp/")
-            else:
-                fileName = protocol.pdbFile.get()
+                fileName = structureHandler.readFromPDBDatabase(os.path.basename(pdbID), dir="/tmp/")
+
+        elif str(type(AS).__name__) == 'SchrodingerAtomStruct':
+            fileName = os.path.abspath(AS.convert2PDB())
         else:
-            if protocol.pdbFileToBeRefined.get() is not None:
-                fileName = os.path.abspath(protocol.pdbFileToBeRefined.get(
-                ).getFileName())
+            fileName = os.path.abspath(AS.getFileName())
 
         structureHandler.read(fileName)
         structureHandler.getStructure()
-        # listOfChains, listOfResidues = structureHandler.getModelsChains()
         return structureHandler.getModelsChains()
 
     def editionListOfChains(self, listOfChains):
-        self.chainList = []
+        chainList = []
         for model, chainDic in listOfChains.items():
             for chainID, lenResidues in chainDic.items():
-                self.chainList.append(
+                chainList.append(
                     '{"model": %d, "chain": "%s", "residues": %d}' %
                     (model, str(chainID), lenResidues))
+        return chainList
 
     def show(self, form, *params):
+        inputParams, outputParam = self.getInputOutput(form)
         protocol = form.protocol
         try:
-            listOfChains, listOfResidues = self.getModelsChainsStep(protocol)
+            listOfChains, listOfResidues = self.getModelsChainsStep(protocol, inputParams[0])
         except Exception as e:
             print("ERROR: ", e)
             return
 
-        self.editionListOfChains(listOfChains)
+        chainList = self.editionListOfChains(listOfChains)
         finalChainList = []
-        for i in self.chainList:
+        for i in chainList:
             finalChainList.append(pwobj.String(i))
         provider = ListTreeProviderString(finalChainList)
         dlg = dialog.ListDialog(form.root, "Model chains", provider,
                                 "Select one of the chains (model, chain, "
                                 "number of chain residues)")
-        form.setVar('inputStructureChain', dlg.values[0].get())
+        form.setVar(outputParam[0], dlg.values[0].get())
+
+SelectChainWizard().addTarget(protocol=emprot.ProtImportSequence,
+                              targets=['inputStructureChain'],
+                              inputs=[['pdbId', 'pdbFile']],
+                              outputs=['inputStructureChain'])
+
+class SelectResidueWizard(SelectChainWizard):
+    _targets, _inputs, _outputs = [], {}, {}
+
+    def editionListOfResidues(self, modelsFirstResidue, model, chain):
+      residueList = []
+      for modelID, chainDic in modelsFirstResidue.items():
+        if int(model) == modelID:
+          for chainID, seq_number in chainDic.items():
+            if chain == chainID:
+              for i in seq_number:
+                residueList.append('{"index": %d, "residue": "%s"}' % (i[0], str(i[1])))
+      return residueList
+
+    def getResidues(self, form, inputParams):
+      protocol = form.protocol
+      inputObj = getattr(protocol, inputParams[0]).get()
+      if issubclass(type(inputObj), emobj.AtomStruct):
+          try:
+            modelsLength, modelsFirstResidue = self.getModelsChainsStep(protocol, inputParams[0])
+          except Exception as e:
+            print("ERROR: ", e)
+            return
+          selection = getattr(protocol, inputParams[1]).get()
+          struct = json.loads(selection)  # From wizard dictionary
+          chain, model = struct["chain"].upper().strip(), int(struct["model"])
+
+          residueList = self.editionListOfResidues(modelsFirstResidue, model, chain)
+          finalResiduesList = []
+          for i in residueList:
+            finalResiduesList.append(emobj.String(i))
+
+      elif issubclass(type(inputObj), emobj.Sequence) or str(type(inputObj).__name__) == 'SequenceVariants':
+          finalResiduesList = []
+          for i, res in enumerate(inputObj.getSequence()):
+            stri = '{"index": %s, "residue": "%s"}' % (i + 1, RESIDUES1TO3[res])
+            finalResiduesList.append(emobj.String(stri))
+
+      return finalResiduesList
+
+    def show(self, form, *params):
+      inputParams, outputParam = self.getInputOutput(form)
+      finalResiduesList = self.getResidues(form, inputParams)
+
+      provider = ListTreeProviderString(finalResiduesList)
+      dlg = dialog.ListDialog(form.root, "Chain residues", provider,
+                              "Select one residue (residue number, "
+                              "residue name)")
+      roiStr = ''
+      idxs = [json.loads(dlg.values[0].get())['index'], json.loads(dlg.values[-1].get())['index']]
+      inSeq = False
+      for residue in finalResiduesList:
+          if json.loads(residue.get())['index'] == idxs[0]:
+              inSeq = True
+          elif json.loads(residue.get())['index'] == idxs[-1]:
+              inSeq = False
+              roiStr += RESIDUES3TO1[json.loads(residue.get())['residue']]
+              break
+
+          if inSeq:
+              roiStr += RESIDUES3TO1[json.loads(residue.get())['residue']]
+
+      intervalStr = '{"index": "%s-%s", "residues": "%s"}' % (idxs[0], idxs[1], roiStr)
+      form.setVar(outputParam[0], intervalStr)
+
+
 
 class PythonFormulaeWizard(pwizard.Wizard):
     """Assist in the creation of python formula to be evaluated. In Steps"""
@@ -240,26 +377,11 @@ class PythonFormulaeWizard(pwizard.Wizard):
         if d.resultYes():
             form.setVar('formula',d.getFormula())
             
-class SelectAttributeWizard(pwizard.Wizard):
-  """Base wizard for selecting an attribute from those contained in the items of a given input
-  inputParam: Name of the input parameter where the items are stored
-  outputParam:
+class SelectAttributeWizard(VariableWizard):
+  """Wizard to select attributes stored in a scipion object or set
   """
   _targets, _inputs, _outputs = [], {}, {}
 
-  def addTarget(self, protocol, targets, inputs, outputs):
-      self._targets += [(protocol, targets)]
-      self._inputs.update({protocol: inputs})
-      self._outputs.update({protocol: outputs})
-
-  def getInputOutput(self, form):
-      '''Retrieving input and output corresponding to the protocol where the wizard is used'''
-      outParam = ''
-      for target in self._targets:
-          if form.protocol.__class__ == target[0]:
-              inParam, outParam = self._inputs[target[0]], self._outputs[target[0]]
-      return inParam, outParam
-
   def getFirstItem(self, form, inputParam):
       inputPointer = getattr(form.protocol, inputParam)
       if issubclass(inputPointer.__class__, pwobj.PointerList):
